pub struct Metadata {
pub entries: Vec<(TransactionMetadatumLabel, TransactionMetadatum)>,
pub encodings: Option<MetadataEncoding>,
}Expand description
Collection of TransactionMetadatums indexed by TransactionMetadatumLabels Handles the extremely rare edge-case of in previous generations allowing duplicate metadatum labels.
Fields
entries: Vec<(TransactionMetadatumLabel, TransactionMetadatum)>encodings: Option<MetadataEncoding>Implementations
Sourceimpl Metadata
impl Metadata
pub fn new() -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn set(
&mut self,
label: TransactionMetadatumLabel,
datum: TransactionMetadatum,
)
pub fn set( &mut self, label: TransactionMetadatumLabel, datum: TransactionMetadatum, )
Replaces all metadatums of a given label, if any exist.
Sourcepub fn get(
&self,
label: TransactionMetadatumLabel,
) -> Option<&TransactionMetadatum>
pub fn get( &self, label: TransactionMetadatumLabel, ) -> Option<&TransactionMetadatum>
Gets the Metadatum corresponding to a given label, if it exists. Note: In the case of duplicate labels this only returns the first metadatum. This is an extremely rare occurence on-chain but can happen.
Sourcepub fn get_all(
&self,
label: TransactionMetadatumLabel,
) -> Option<Vec<&TransactionMetadatum>>
pub fn get_all( &self, label: TransactionMetadatumLabel, ) -> Option<Vec<&TransactionMetadatum>>
In the extremely unlikely situation there are duplicate labels, this gets all of a single label