TransactionBuilder

Struct TransactionBuilder 

pub struct TransactionBuilder { /* private fields */ }

Implementations

Source

impl TransactionBuilder

pub fn select_utxos( &mut self, strategy: CoinSelectionStrategyCIP2, ) -> Result<(), TxBuilderError>

This automatically selects and adds inputs from {inputs} consisting of just enough to cover the outputs that have already been added. This should be called after adding all certs/outputs/etc and will be an error otherwise. Uses CIP2: https://github.com/cardano-foundation/CIPs/blob/master/CIP-0002/CIP-0002.md Adding a change output must be called after via TransactionBuilder::add_change_if_needed() This function, diverging from CIP2, takes into account fees and will attempt to add additional inputs to cover the minimum fees. This does not, however, set the txbuilder’s fee.

pub fn add_input( &mut self, result: InputBuilderResult, ) -> Result<(), TxBuilderError>

pub fn add_utxo(&mut self, result: InputBuilderResult)

pub fn fee_for_input( &self, result: &InputBuilderResult, ) -> Result<Coin, TxBuilderError>

calculates how much the fee would increase if you added a given output

pub fn add_reference_input(&mut self, utxo: TransactionUnspentOutput)

Add a reference input. Must be called BEFORE adding anything (inputs, certs, etc) that refer to this reference input.

pub fn add_output( &mut self, builder_result: SingleOutputBuilderResult, ) -> Result<(), TxBuilderError>

Add explicit output via a TransactionOutput object

pub fn fee_for_output( &self, builder: &SingleOutputBuilderResult, ) -> Result<Coin, TxBuilderError>

calculates how much the fee would increase if you added a given output

pub fn set_fee(&mut self, fee: Coin)

pub fn set_donation(&mut self, donation: Coin)

pub fn set_current_treasury_value(&mut self, current_treasury_value: Coin)

pub fn set_ttl(&mut self, ttl: Slot)

pub fn set_validity_start_interval(&mut self, validity_start_interval: Slot)

pub fn add_cert(&mut self, result: CertificateBuilderResult)

pub fn add_proposal(&mut self, result: ProposalBuilderResult)

pub fn add_vote(&mut self, result: VoteBuilderResult)

pub fn get_withdrawals(&self) -> Option<Withdrawals>

pub fn add_withdrawal(&mut self, result: WithdrawalBuilderResult)

pub fn get_auxiliary_data(&self) -> Option<AuxiliaryData>

pub fn set_auxiliary_data(&mut self, new_aux_data: AuxiliaryData)

pub fn add_auxiliary_data(&mut self, new_aux_data: AuxiliaryData)

pub fn add_mint( &mut self, result: MintBuilderResult, ) -> Result<(), TxBuilderError>

pub fn get_mint(&self) -> Option<Mint>

Returns a copy of the current mint state in the builder

pub fn new(cfg: TransactionBuilderConfig) -> Self

pub fn add_collateral( &mut self, result: InputBuilderResult, ) -> Result<(), TxBuilderError>

pub fn add_required_signer(&mut self, hash: Ed25519KeyHash)

pub fn set_network_id(&mut self, network_id: NetworkId)

pub fn network_id(&self) -> Option<NetworkId>

pub fn get_explicit_input(&self) -> Result<Value, TxBuilderError>

does not include refunds or withdrawals

pub fn get_implicit_input(&self) -> Result<Value, TxBuilderError>

withdrawals and refunds

pub fn get_total_input(&self) -> Result<Value, TxBuilderError>

Return explicit input plus implicit input plus mint

pub fn get_total_output(&self) -> Result<Value, TxBuilderError>

Return explicit output plus implicit output plus burn/donation (does not consider fee directly)

pub fn get_explicit_output(&self) -> Result<Value, TxBuilderError>

does not include fee

pub fn get_deposit(&self) -> Result<Coin, TxBuilderError>

pub fn get_fee_if_set(&self) -> Option<Coin>

pub fn set_collateral_return(&mut self, output: TransactionOutput)

pub fn full_size(&self) -> Result<usize, TxBuilderError>

pub fn output_sizes(&self) -> Vec<usize>

pub fn build_for_evaluation( &self, algo: ChangeSelectionAlgo, change_address: &Address, ) -> Result<TxRedeemerBuilder, TxBuilderError>

Builds the transaction and moves to the next step redeemer units can be added and a draft tx can be evaluated NOTE: is_valid set to true

pub fn build( &mut self, algo: ChangeSelectionAlgo, change_address: &Address, ) -> Result<SignedTxBuilder, TxBuilderError>

Builds the transaction and moves to the next step where any real witness can be added NOTE: is_valid set to true

pub fn set_exunits(&mut self, redeemer: RedeemerWitnessKey, ex_units: ExUnits)

used to override the exunit values initially provided when adding inputs

pub fn min_fee(&self, script_calulation: bool) -> Result<Coin, TxBuilderError>

warning: sum of all parts of a transaction must equal 0. You cannot just set the fee to the min value and forget about it warning: min_fee may be slightly larger than the actual minimum fee (ex: a few lovelaces) this is done to simplify the library code, but can be fixed later