pub fn hash_script_data(
redeemers: &Redeemers,
cost_models: &CostModels,
datums: Option<&NonemptySetPlutusData>,
_encoding: Option<&TransactionWitnessSetEncoding>,
) -> ScriptDataHashExpand description
Calculates the hash for script data (no plutus scripts) if it is necessary. Returns None if it was not necessary (no datums/redeemers) to include.
Most users will not directly need this as when using the builders it will be invoked for you.